Python libraries and scripts for converting numbers using the [Mnemonic Major System].

After

    pip install .

`major_words --help` will show the flags to the executable script
`major_words`.



[Mnemonic Major System]: https://en.wikipedia.org/wiki/Mnemonic_major_system
